@@ -3,10 +3,16 @@
 
 # PARAMETERS
 import yaml
+import subprocess
 
 class Parameters:
     def __init__(self):
-        stream = open("/home/laurent/Documents/PyJoke/parameters.yml", "r")
+        import os
+        script_dir = os.path.dirname(__file__) #<-- absolute dir the script is in
+        rel_path = "parameters.yml"
+        abs_file_path = os.path.join(script_dir, rel_path)
+
+        stream = open(abs_file_path, "r")
         docs = yaml.load_all(stream)
         for doc in docs:
             self.database = doc["database"]["use"]
@@ -15,7 +21,10 @@ class Parameters:
             self.passwd = doc["database"]["passwd"]
             self.db = doc["database"]["db"]
             self.table = doc["database"]["table"]
-            self.sqlite = doc["database"]["sqlite"]
+
+            script_dir = os.path.dirname(__file__) #<-- absolute dir the script is in
+            rel_path = doc["database"]["sqlite"]
+            self.sqlite = os.path.join(script_dir, rel_path)
 
             self.lang = doc["pyjoke"]["lang"]
             self.jokelen = doc["pyjoke"]["jokelen"]
@@ -23,6 +32,19 @@ class Parameters:
             self.nao = doc["pyjoke"]["nao"]
 
             self.postag = doc["postag"]["active"]
+
+            try:
+                subprocess.call(["tree-tagger"])
+            except OSError as e:
+                if e.errno == os.errno.ENOENT:
+                    # handle file not found error.
+                    print "[!] PyJoke parameters error: tree-tagger not found"
+                    print "[!] PosTag deactivated"
+                    self.postag = 0
+                else:
+                    #nope
+                    raise
+
             self.default = doc["postag"]["default"]
             self.adj = doc["postag"]["adj"]
             self.noun = doc["postag"]["noun"]
