@@ -22,8 +22,8 @@ import os
 from collections import OrderedDict
 
 # PERSO
-from include.KeywordsList import *
-from include.Parameters import *
+from KeywordsList import *
+from Parameters import *
 
 class PyJoke:
     # Init parameters
@@ -106,9 +106,6 @@ class PyJoke:
                 query = query + " OR  `text` LIKE  \'%"+keyw.getWord(x)+"%\'";
             query = query + ") ORDER BY score DESC "
 
-        if self.params.debug:
-            print "DATABASE"+self.params.sqlite
-
         ##    Connection to Database
         #################################
         if self.params.database=="mysql":
@@ -121,9 +118,10 @@ class PyJoke:
         elif self.params.database=="sqlite":
             import sqlite3
             conn = sqlite3.connect(self.params.sqlite)
-            conn.enable_load_extension(True)
+            if not self.params.nao:
+                conn.enable_load_extension(True)
         else:
-            print "Error: Database?"
+            print "[!] Error: Database should be sqlite or mysql"
 
         # Cursor
         c = conn.cursor()
